@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -13,10 +13,7 @@ our @EXPORT_OK = qw(
     beadwork
 );
 
-use Clone;
 use HTML::AutoTag;
-use Math::Matrix;
-
 use Spreadsheet::HTML::Engine;
 use Spreadsheet::HTML::Presets;
 use Spreadsheet::HTML::File::Loader;
@@ -54,14 +51,14 @@ sub generate {
 
     } elsif ($args{theta} == -90) {
 
-        $args{data} = [ CORE::reverse @{ Math::Matrix::transpose( $args{data} ) }];
+        $args{data} = [ CORE::reverse @{ _transpose( $args{data} ) }];
         $args{data} = ($args{pinhead} and !$args{headless})
             ? [ map [ @$_[1 .. $#$_], $_->[0] ], @{ $args{data} } ]
             : [ map [ CORE::reverse @$_ ], @{ $args{data} } ];
 
     } elsif ($args{theta} == 90) { # east
 
-        $args{data} = Math::Matrix::transpose( $args{data} );
+        $args{data} = _transpose( $args{data} );
         $args{data} = ($args{pinhead} and !$args{headless})
             ? [ map [ @$_[1 .. $#$_], $_->[0] ], @{ $args{data} } ]
             : [ map [ CORE::reverse @$_ ], @{ $args{data} } ];
@@ -80,11 +77,11 @@ sub generate {
 
     } elsif ($args{theta} == -270) { # west
 
-        $args{data} = [@{ Math::Matrix::transpose( $args{data} ) }];
+        $args{data} = [@{ _transpose( $args{data} ) }];
 
     } elsif ($args{theta} == 270) {
 
-        $args{data} = [ CORE::reverse @{ Math::Matrix::transpose( $args{data} ) }];
+        $args{data} = [ CORE::reverse @{ _transpose( $args{data} ) }];
     }
 
     if ($args{animate}) {
@@ -130,7 +127,7 @@ sub _process {
     }
 
     my $empty = exists $args->{empty} ? $args->{empty} : '&nbsp;';
-
+    my $tag   = ($args->{headless} or $args->{matrix}) ? 'td' : 'th';
     for my $row (0 .. $args->{_max_rows} - 1) {
 
         unless ($args->{_layout}) {
@@ -138,7 +135,6 @@ sub _process {
             pop  @{ $data->[$row] } for $args->{_max_cols} .. $#{ $data->[$row] };                 # truncate
         }
 
-        my $tag = (!$row and !($args->{headless} or $args->{matrix})) ? 'th' : 'td';
         for my $col (0 .. $#{ $data->[$row] }) {
 
             my ( $cdata, $attr ) = ( $data->[$row][$col], undef );
@@ -155,6 +151,7 @@ sub _process {
                 (keys( %$attr )    ? (attr => $attr)   : ()),
             };
         }
+        $tag = 'td';
     }
 
     if ($args->{cache} and $self and !$self->{is_cached}) {
@@ -182,8 +179,8 @@ sub _make_table {
         my $head = shift @body unless $args{matrix} and scalar @{ $args{data} } > 2;
         my $foot = pop @body if !$args{matrix} and $args{tgroups} > 1 and scalar @{ $args{data} } > 2;
 
-        my $head_row  = { tag => 'tr', attr => $args{tr}, cdata => $head };
-        my $foot_row  = { tag => 'tr', attr => $args{tr}, cdata => $foot };
+        my $head_row  = { tag => 'tr', attr => $args{'thead.tr'}, cdata => $head };
+        my $foot_row  = { tag => 'tr', attr => $args{'tfoot.tr'}, cdata => $foot };
         my $body_rows = [ map { tag => 'tr', attr => $args{tr}, cdata => $_ }, @body ];
 
         if (int($args{group} || 0) > 1) {
@@ -286,11 +283,12 @@ sub _args {
         encodes => exists $args->{encodes} ? $args->{encodes} : '',
         indent  => $args->{indent},
         level   => $args->{level},
-        sorted  => $args->{sorted_attrs}
+        sorted  => $args->{sorted_attrs},
     );
 
     return ( $self, $self->{data}, $args ) if $self and $self->{is_cached};
 
+    $args->{worksheet} ||= 1;
     $data = Spreadsheet::HTML::File::Loader::parse( $args ) if $args->{file};
     $data = [ $data ] unless ref($data);
     $data = [ $data ] unless ref($data->[0]);
@@ -303,9 +301,7 @@ sub _args {
         ];
     }
 
-    if ($args->{apply}) {
-        $data = Spreadsheet::HTML::Engine::apply( $data, $args->{apply} );
-    }
+    $data = Spreadsheet::HTML::Engine::apply( $data, $args->{apply} ) if $args->{apply};
 
     $args->{_max_rows} = scalar @{ $data }      || 1;
     $args->{_max_cols} = scalar @{ $data->[0] } || 1;
@@ -317,7 +313,7 @@ sub _args {
         $args->{_max_cols} = $fill{col} if (int($fill{col} || 0)) > ($args->{_max_cols});
     }
 
-    return ( $self, Clone::clone($data), $args );
+    return ( $self, [ map [@$_], @$data], $args );
 }
 
 sub _expand_code_or_hash {
@@ -335,6 +331,16 @@ sub _expand_code_or_hash {
     return ( $cdata, $attr );
 }
 
+# credit: Math::Matrix
+sub _transpose {
+    my $data = shift;
+    my @trans;
+    for my $i (0 .. $#{ $data->[0] }) {
+        push @trans, [ map $_->[$i], @$data ]
+    }
+    return \@trans;
+}
+
 sub _range {grep!(($_-$_[0])%($_[2]||1)),$_[0]..$_[1]}
 
 
@@ -347,6 +353,8 @@ Spreadsheet::HTML - Just another HTML table generator.
 
 =head1 SYNOPSIS
 
+Object oriented interface:
+
     use Spreadsheet::HTML;
 
     $data = [ [qw(a1 a2 a3)], [qw(b1 b2 b3)], [qw(c1 c2 c3)] ];
@@ -356,8 +364,7 @@ Spreadsheet::HTML - Just another HTML table generator.
     print $generator->portrait;
     print $generator->landscape( encodes => '<>' );
 
-    # load from files (first table found)
-    $generator = Spreadsheet::HTML->new( file => 'data.xls', cache => 1 );
+    $generator = Spreadsheet::HTML->new( file => 'data.xls', worksheet => 2 );
     print $generator->generate( preserve => 1 );
 
 Procedural interface:
@@ -377,10 +384,13 @@ Rewrap existing tables from Excel, HTML, JSON, CSV and YAML files.
 
 THIS MODULE IS AN ALPHA RELEASE! Although we are very close to BETA.
 
-=head1 CLI TOOL
+=head1 CLI TOOLS
 
-A command line interface tool is available for you to quickly
-generate tables without writing a script: C<mktable>
+=over 4
+
+=item * C<mktable>
+
+Quickly generate tables without writing a script:
 
   $ mktable landscape --param file=data.xls --param preserve=1 > out.html
 
@@ -395,6 +405,13 @@ your default browser:
 
 Run C<mktable --man> for more documentation.
 
+=item * C<benchmark-spreadsheet-html>
+
+This tool runs benchmarks against several different HTML table generators
+available on CPAN. See C<benchmark-spreadsheet-html --man> for more.
+
+=back
+
 =head1 METHODS
 
 All methods (except C<new>) are exportable as functions. They all
@@ -488,13 +505,15 @@ are XLS, CSV, JSON, YAML and HTML (first table found).
 
   file => 'foo.json'
 
-If you want to filter your database queries then install
+If you want to filter your database queries then please see
 L<DBIx::HTML> which uses this module as its generator.
 
-  use DBIx::HTML;
-  my $generator = DBIx::HTML->connect( @db_credentials );
-  $generator->do( $query, @bind_args );
-  print $table->portrait( %params );
+=item * C<worksheet>
+
+If multiple worksheets or data tables are present, use this
+parameter to select which one (index 1 based).
+
+  worksheet => 3 # the third data table or worksheet found  
 
 =item * C<preserve>
 
@@ -627,7 +646,7 @@ any reference to C<headings> will be discarded too.
 
 =item * C<animate: 0 or 1>
 
-Animate the table cells. See *L<Spreadsheet::HTML::Presets::Animate>.
+Animate the table cells. See L<Spreadsheet::HTML::Presets::Animate>.
 
 =item * C<headings>
 
@@ -635,11 +654,11 @@ Apply callback subroutine to each cell in headings row.
 
   headings => sub { join(" ", map {ucfirst lc $_} split "_", shift) }
 
-Or apply hash ref as attributes:
+Or apply hash reference as attributes:
 
   headings => { class => 'some-class' }
 
-Or both:
+Or both via array reference:
 
   headings => [ sub { uc shift }, { class => "foo" } ]
 
@@ -739,6 +758,9 @@ Hash ref. Apply these attributes to the specified tag.
 
   tr => { style => { background => [qw( color1 color2 )]' } }
 
+Does not apply to <tr> groups found within <thead> or <tfoot>.
+(See C<thead.tr> and C<tfoot.tr> below.)
+
 =item * C<th>
 
 =item * C<td>
@@ -777,6 +799,16 @@ tags within a colgroup tag. Same usage as C<colgroup>.
 
   col => [ { span => 20 }, { span => 1, class => 'end' } ]
 
+=item * C<thead.tr>
+
+When C<tgroups> is 1 or 2, this tag parameter is available to control
+the attributes of the <tr> tag within the <thead> group.
+
+=item * C<tfoot.tr>
+
+When C<tgroups> is 2, this tag parameter is available to control
+the attributes of the <tr> tag within the <tfoot> group.
+
 =back
 
 =head2 PRESETS
@@ -827,14 +859,6 @@ Used to generate HTML. Handles indentation and HTML entity encoding.
 Uses L<Tie::Hash::Attribute> to handle rotation of class attributes
 and L<HTML::Entities> for encoding of CDATA.
 
-=item * L<Math::Matrix>
-
-Used for transposing data from portrait to landscape.
-
-=item * L<Clone>
-
-Useful for preventing data from being clobbered.
-
 =back
 
 =head1 OPTIONAL
@@ -957,6 +981,10 @@ Thank you very much! :)
 
 Helped with Makefile.PL suggestions and corrections.
 
+=item * L<Math::Matrix>
+
+Implementation of 2D array transposition.
+
 =back
 
 =head1 AUTHOR
