@@ -47,15 +47,17 @@ sub checkerboard {
 
     my $colors = $args->{colors} ? $args->{colors} : [qw(red green)];
     $colors = [ $colors ] unless ref $colors;
-    $args->{extra} ||= 'white';
-    push @$colors, $args->{extra} unless $args->{_max_cols} % @$colors;
+
+    my @rows;
+    for my $row (0 .. $args->{_max_rows} - 1) {
+        push @rows, ( "-r$row" => { style => { 'background-color' => [@$colors] } } );
+        Tie::Hash::Attribute::_rotate( $colors );
+    }
 
     my @args = (
-        matrix   => 1,
-        headings => sub { join(' ', map { sprintf '<b>%s</b>', ucfirst(lc($_)) } split ('_', shift || '')) },
         @_,
         wrap => 0,
-        td => { %{ $args->{td} || {} }, style  => { %{ $args->{td}{style} || {} }, 'background-color' => $colors } },
+        @rows,
     );
 
     $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
@@ -75,6 +77,9 @@ sub banner {
                 ->new( -d => $args->{dir}, -f => $args->{emboss} ? 'block' : 'banner' )
                 ->figify( -A => uc( $args->{text} || '' ), -w => 9999 );
         };
+        if ($@) {
+            $data = [ ['Error'], ["could not create banner: $@"] ];
+        }
 
         if (@banner) {
             push @cells, ( fill => join 'x', scalar( @banner ), length( $banner[0] ) );
@@ -103,8 +108,12 @@ sub banner {
             }
         }
     }
+    else {
+        $data = [ ['could not create banner'], [ 'Text::FIGlet not installed' ] ];
+    }
 
     my @args = (
+        data => $data,
         @_,
         @cells,
         wrap => 0,
@@ -218,6 +227,7 @@ sub calendar {
         
         push @cal_args, ( data => \@flat );
 
+        $args->{ '-' . Time::Piece->new->mday } = $args->{today};
         my %day_args = map {($_ => $args->{$_})} grep /^-\d+$/, keys %$args;
         for (keys %day_args) {
             my $day = abs($_);
@@ -244,6 +254,7 @@ sub calendar {
     my @args = (
         @cal_args,
         @_,
+        td => { %{ $args->{td} || {} }, style  => { %{ $args->{td}{style} || {} }, 'text-align' => 'right' } },
         wrap    => 7,
         theta   => 0,
         flip    => 0,
@@ -381,7 +392,7 @@ sub _js_wrapper {
 
 =head1 NAME
 
-Spreadsheet::HTML::Presets - Preset tables for fun and games.
+Spreadsheet::HTML::Presets - Generate preset HTML tables.
 
 =head1 DESCRIPTION
 
@@ -425,11 +436,13 @@ Will generate and display a banner using the given C<text> in the
 'banner' font. Set C<emboss> to a true value and the font 'block'
 will be emulated by highlighting the left and bottom borders of the cell.
 Set the foreground color with C<on> and the background with C<off>.
-You Must have L<Text::FIGlet> installed in order to use this preset.
+You Must have L<Text::FIGlet> installed AND configured in order to use
+this preset. If Text::FIGlet cannot find the fonts directory then it
+will silently fail and produce no banner.
 
   banner( dir => '/path/to/figlet/fonts', text => 'HI', on => 'red' )
 
-=item * C<calendar( month, year, %params )>
+=item * C<calendar( month, year, today, %params )>
 
 Generates a static calendar. Defaults to current month and year.
 
@@ -439,6 +452,10 @@ Mark a day of the month like so:
 
   calendar( month => 12, -25 => { bgcolor => 'red' } )
 
+Or mark today, whenever it is:
+
+  calendar( today => { bgcolor => 'red' } )
+
 Default rules still apply to styling columns by any heading:
 
   calendar( -Tue => { class => 'ruby' } )
@@ -451,11 +468,13 @@ Generates a static maze.
 
 =item * C<checkers( %params )>
 
-Generates a static checkers game board (US).
+Generates a checkers game board (US). Currently you can only
+move the pieces around without regard to any rules.
 
 =item * C<chess( %params )>
 
-Generates a static chess game board.
+Generates a chess game board. Currently you can only
+move the pieces around without regard to any rules.
 
 =back
 
@@ -463,19 +482,34 @@ Generates a static chess game board.
 
 =over 4
 
-=item *L<Spreadsheet::HTML::Presets::Animate>
+=item * L<Spreadsheet::HTML::Presets::Animate>
 
-=item *L<Spreadsheet::HTML::Presets::Beadwork>
+Provides the animate param.
 
-=item *L<Spreadsheet::HTML::Presets::Calculator>
+=item * L<Spreadsheet::HTML::Presets::Beadwork>
 
-=item *L<Spreadsheet::HTML::Presets::Conway>
+Turn cell backgrounds into 8-bit pixel art.
 
-=item *L<Spreadsheet::HTML::Presets::Chess>
+=item * L<Spreadsheet::HTML::Presets::Calculator>
 
-=item *L<Spreadsheet::HTML::Presets::Handson>
+A simple HTML table calculator.
 
-=item *L<Spreadsheet::HTML::Presets::Sudoku>
+=item * L<Spreadsheet::HTML::Presets::Conway>
+
+Turn cell backgrounds into Conway's game of life.
+
+=item * L<Spreadsheet::HTML::Presets::Chess>
+
+Work in progress. Hope to interface with a pre-existing
+Javascript Chess engine someday.
+
+=item * L<Spreadsheet::HTML::Presets::Handson>
+
+Handsontable HTML tables. See L<http://handsontable.com>.
+
+=item * L<Spreadsheet::HTML::Presets::Sudoku>
+
+Generate 9x9 HTML table sudoku boards.
 
 =back
 
